import themidibus.*; //Import the library

MidiBus myBus; // The MidiBus

// An index we'll use to load the appropriate image
int index = 0;

// The image filenames that are in the "data/" folder
String[] imageNames = 
{ "01-SqueezeKick.jpeg", "02-WoodenSpoon1.jpeg", "03-WoodenSpoon2.jpeg",
  "04-BeansCan.jpeg", "05-CoffeeTin.jpeg", "06-LargBowl.jpeg",
  "07-Grinder.jpeg", "08-EskaCan.jpeg", "09-GlassJug.jpeg",
  "10-Oatmeal.jpeg", "11-SmallBowl.jpeg", "12-Squeeze.jpeg",
  "13-VitaminShake.jpeg", "14-WaterBottleTing.jpeg", "15-WaterDrop.jpeg",
  "16-Whisk.jpeg", "18-WickerBasket2.jpeg", "18-WickerBasket2.jpeg",
  "19-WireRack.jpeg", "19-WireRack.jpeg", "19-WireRack.jpeg",
  "19-WireRack.jpeg", "19-WireRack.jpeg", "19-WireRack.jpeg"};

// An aray of images we load in the setup loop
PImage[] images = new PImage[imageNames.length];

// The lowest/starting note on your controller
int root = 53;

// Number of images/notes you are mapping
int numNotes = 24;

// Midi channel number - change this so you only receive notes from a specific MIDI channel on your device.
// Note that this is zero-indexed here, but is usually referred to as one-indexed in the regular world
// That means if you want to receive MIDI messages from MIDI Channel 3 on your controller,
// set this to "2", not "3".
int MIDIchannel = 2;

// Setup loop where we load the MIDI Bus, 
void setup() {
  
  // Either run in fullscreen or a smaller window - comment/uncomment as appropriate, you can only have one uncommented at a time.
  size(600, 400);
  //fullScreen();
  
  // List all available Midi devices on STDOUT. This will show each device's index and name. Use this below
  // so you only receive messages from the appropriate device.
  MidiBus.list(); 

  // Either you can
  //                   Parent In Out
  //                     |    |  |
  //myBus = new MidiBus(this, 0, 1); // Create a new MidiBus using the device index to select the Midi input and output devices respectively.

  // or you can ...
  //                   Parent         In                   Out
  //                     |            |                     |
  //myBus = new MidiBus(this, "IncomingDeviceName", "OutgoingDeviceName"); 
  // Create a new MidiBus using the device names to select the Midi input and output devices respectively.

  // or for testing you could ...
  //                 Parent  In        Out
  //                   |     |          |
  myBus = new MidiBus(this, "OP-Z", 1); // Create a new MidiBus with an input device and the default Java Sound Synthesizer as the output device.

  // Load the images into the Pimage array - if they're big they take longer, so resize your images beforehand
  // so that they are as small as you find acceptable without losing resolution.
  for (int i=0; i < imageNames.length; i++){
    String imageName = imageNames[i];
    images[i] = loadImage(imageName);
    images[i].resize(width,0); // This resizes the images to fit the width of the window
  }

}

// Main draw loop that repeats forever
void draw() {
  // Draw whatver the latest note-on MIDI message number's associated image is to the screen
  // You could likley make this more efficient by only drawing if that index has changed
  image(images[index], 0, 0); 
}

// Recieives MIDI messages from the MIDI bus and runs this code whenever it gets a noteOn message
// See the MIDI library examples for more details
void noteOn(int channel, int pitch, int velocity) {
  println("Got it");
  if(channel == MIDIchannel){
    index = pitch - root;
    index = index%numNotes;  
  }
}
